==========
Resourcify
==========

Resourcify is a library module for making ReST client easy.

* License: MIT

Getting Started
===============

Resourcify can be installed from GIT using pip::

    pip install resourcify 
